@@ -53,9 +53,6 @@ static char sccsid[] = "@(#)fingerd.c	8.1 (Berkeley) 6/4/93";
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
-#if INET6
-#include <netinet6/in6.h>
-#endif /* INET6 */
 #include <arpa/inet.h>
 #include <errno.h>
 
@@ -83,11 +80,7 @@ main(argc, argv)
 	register char *lp;
 	struct hostent *hp;
 #if INET6
-	union {
-	  struct sockaddr sa;
-	  struct sockaddr_in sin;
-	  struct sockaddr_in6 sin6;
-	} su;
+	union sockaddr_union su;
 #else /* INET6 */
 	struct sockaddr_in sin;
 #endif /* INET6 */
@@ -142,9 +135,9 @@ main(argc, argv)
 	if (!fgets(line, sizeof(line), stdin))
 		exit(1);
 
-#if 1
+#if INNER
 	syslog(LOG_NOTICE, "query on '%s'", line);
-#endif /* 1 */
+#endif /* INNER */
 	
 	comp = &av[1];
 	for (lp = line, ap = &av[2];;) {
